@@ -1,10 +1,12 @@
 import os
 import platform
+import sys
 
 
 class Parameters:
     # CONFIGURACION PATH Y TESTCASE
-    current_path = os.path.abspath(os.path.join(__file__, "../../../../../"))
+    current_path = os.path.abspath(os.path.join(os.getcwd(), "../.."))
+    sys.path.append(current_path)
     file_name_stored = None
     env = None
 
@@ -37,7 +39,6 @@ class Parameters:
     steps_list = []
 
     # CONFIGURACION INCREMENTO AUTO/MANUALEXCEL
-    excel = f"{current_path}\\resources"
     manual_increment = False
     row = 2
 
@@ -72,16 +73,6 @@ class Parameters:
     duration = 60  # Duracion de la prueba (Segundos)
     wait_time = 1  # Duracion de tiempos de espera entre peticiones.
 
-    # CONFIGURACION DE EJECUCION
-    if environment == 'Windows':
-        # DIRECTORIO DE LA EVIDENCIA
-        evidence_route = current_path
-        resource = f"{current_path}\\projects"
-
-    if environment == 'Linux':
-        # DIRECTORIO DE LA EVIDENCIA
-        evidence_route = current_path
-
     # CONFIGURACION PARA NOTIFICACIONES DE TEAMS
     teams_notifications_colors = "#5b5fc7"
     teams_focus_test_colors = "#383966"
\ No newline at end of file
